@@ -45,7 +45,7 @@ class UnifiedBuffer:
         conn.commit()
         conn.close()
 
-    def get(self, n_latest_data: int) -> List:
+    def get_last(self, n_latest_data: int) -> List:
         """
 
         :param n_latest_data:
@@ -61,6 +61,22 @@ class UnifiedBuffer:
         conn.close()
         return rows
 
+    def get_by_update_no(self, update_no: int) -> List:
+        """
+
+        :param update_no:
+        :return: List of (phase_name, green_time)
+        """
+        assert update_no >= 0
+        conn = sqlite3.connect(self.db_path)
+        c = conn.cursor()
+        c.execute(
+            "SELECT Phase,GreenTime FROM Actions WHERE NoUpdate=?", (update_no,))
+        rows = c.fetchall()
+        conn.commit()
+        conn.close()
+        return rows
+
     def wait(self, update_no, sleep_sec=0.5):
         while True:
             conn = sqlite3.connect(self.db_path)
